@@ -151,6 +151,10 @@ class GeneratorTestCase(base.BaseTestCase):
         'list_opt': cfg.ListOpt('list_opt',
                                 default=['1', '2', '3'],
                                 help='a list'),
+        'list_opt_with_bounds': cfg.ListOpt('list_opt_with_bounds',
+                                            default=['1', '2', '3'],
+                                            help='a list',
+                                            bounds=True),
         'list_opt_single': cfg.ListOpt('list_opt_single',
                                        default='1',
                                        help='a list'),
@@ -431,7 +435,12 @@ class GeneratorTestCase(base.BaseTestCase):
 #
 
 # a string with choices (string value)
-# Allowed values: <None>, '', a, b, c
+# Possible values:
+# <None> - <No description provided>
+# '' - <No description provided>
+# a - <No description provided>
+# b - <No description provided>
+# c - <No description provided>
 #choices_opt = a
 ''')),
         ('deprecated opt without deprecated group',
@@ -625,6 +634,17 @@ class GeneratorTestCase(base.BaseTestCase):
 
 # a list (list value)
 #list_opt = 1,2,3
+''')),
+        ('list_opt_with_bounds',
+         dict(opts=[('test', [(None, [opts['list_opt_with_bounds']])])],
+              expected='''[DEFAULT]
+
+#
+# From test
+#
+
+# a list (list value)
+#list_opt_with_bounds = [1,2,3]
 ''')),
         ('list_opt_single',
          dict(opts=[('test', [(None, [opts['list_opt_single']])])],
@@ -1219,7 +1239,13 @@ class MachineReadableGeneratorTestCase(base.BaseTestCase):
                                 'help': '',
                                 'standard_opts': ['choices_opt'],
                                 'opts': [{'advanced': False,
-                                          'choices': (None, '', 'a', 'b', 'c'),
+                                          'choices': [
+                                              (None, None),
+                                              ('', None),
+                                              ('a', None),
+                                              ('b', None),
+                                              ('c', None)
+                                          ],
                                           'default': 'a',
                                           'deprecated_for_removal': False,
                                           'deprecated_opts': [],
@@ -1581,10 +1607,10 @@ class GeneratorRaiseErrorTestCase(base.BaseTestCase):
         with mock.patch('pkg_resources.iter_entry_points', fake_eps):
             self.assertRaises(FakeException, generator.generate, self.conf)
 
-    def test_generator_call_with_no_arguments_raises_error(self):
+    def test_generator_call_with_no_arguments_raises_system_exit(self):
         testargs = ['oslo-config-generator']
         with mock.patch('sys.argv', testargs):
-            self.assertRaises(cfg.RequiredOptError, generator.main, [])
+            self.assertRaises(SystemExit, generator.main, [])
 
 
 class ChangeDefaultsTestCase(base.BaseTestCase):
